@@ -12,7 +12,7 @@ from agentbox.exceptions import SandboxException, format_request_timeout_error
 from agentbox.sandbox.main import SandboxSetup
 from agentbox.sandbox.utils import class_method_variant
 from agentbox.sandbox_sync.adb_shell.adb_shell import ADBShell
-from agentbox.sandbox_sync.filesystem.filesystem import AgentBoxFilesystem as Filesystem
+from agentbox.sandbox_sync.filesystem.filesystem import Filesystem
 from agentbox.sandbox_sync.commands.command import Commands
 from agentbox.sandbox_sync.commands.pty import Pty
 from agentbox.sandbox_sync.sandbox_api import SandboxApi, SandboxInfo
